@@ -2,16 +2,15 @@
 #define OSMPBF_H
 
 // this describes the low-level blob storage
-#include <osmpbf/fileformat.pb.h>
+#include <osmpbf/fileformat.pb.h> // IWYU pragma: export
 
 // this describes the high-level OSM objects
-#include <osmpbf/osmformat.pb.h>
+#include <osmpbf/osmformat.pb.h> // IWYU pragma: export
+
+#define OSMPBF_VERSION "1.3.3"
 
 namespace OSMPBF {
 
-    // library version
-    const char *version = "1.3.0";
-
     // the maximum size of a blob header in bytes
     const int max_blob_header_size = 64 * 1024; // 64 kB
 
